@@ -1,13 +1,16 @@
+from __future__ import unicode_literals
+
 import sys
 
 import mock
+import pykka
 
-from mopidy import OptionalDependencyError, settings
-from mopidy.backends.dummy import DummyBackend
+from mopidy import core, exceptions, settings
+from mopidy.backends import dummy
 
 try:
     from mopidy.frontends.mpris import objects
-except OptionalDependencyError:
+except exceptions.OptionalDependencyError:
     pass
 
 from tests import unittest
@@ -18,15 +21,28 @@ class RootInterfaceTest(unittest.TestCase):
     def setUp(self):
         objects.exit_process = mock.Mock()
         objects.MprisObject._connect_to_dbus = mock.Mock()
-        self.backend = DummyBackend.start().proxy()
-        self.mpris = objects.MprisObject()
+        self.backend = dummy.DummyBackend.start(audio=None).proxy()
+        self.core = core.Core.start(backends=[self.backend]).proxy()
+        self.mpris = objects.MprisObject(core=self.core)
 
     def tearDown(self):
-        self.backend.stop()
+        pykka.ActorRegistry.stop_all()
 
     def test_constructor_connects_to_dbus(self):
         self.assert_(self.mpris._connect_to_dbus.called)
 
+    def test_fullscreen_returns_false(self):
+        result = self.mpris.Get(objects.ROOT_IFACE, 'Fullscreen')
+        self.assertFalse(result)
+
+    def test_setting_fullscreen_fails_and_returns_none(self):
+        result = self.mpris.Set(objects.ROOT_IFACE, 'Fullscreen', 'True')
+        self.assertIsNone(result)
+
+    def test_can_set_fullscreen_returns_false(self):
+        result = self.mpris.Get(objects.ROOT_IFACE, 'CanSetFullscreen')
+        self.assertFalse(result)
+
     def test_can_raise_returns_false(self):
         result = self.mpris.Get(objects.ROOT_IFACE, 'CanRaise')
         self.assertFalse(result)
@@ -60,7 +76,7 @@ class RootInterfaceTest(unittest.TestCase):
         self.assertEquals(result, 'foo')
         settings.runtime.clear()
 
-    def test_supported_uri_schemes_is_empty(self):
+    def test_supported_uri_schemes_includes_backend_uri_schemes(self):
         result = self.mpris.Get(objects.ROOT_IFACE, 'SupportedUriSchemes')
         self.assertEquals(len(result), 1)
         self.assertEquals(result[0], 'dummy')
