@@ -4,7 +4,7 @@ import datetime
 import json
 
 from mopidy.models import (
-    Artist, Album, TlTrack, Track, Playlist,
+    Artist, Album, TlTrack, Track, Playlist, SearchResult,
     ModelJSONEncoder, model_json_decoder)
 
 from tests import unittest
@@ -707,7 +707,7 @@ class PlaylistTest(unittest.TestCase):
         self.assertEqual(playlist.length, 3)
 
     def test_last_modified(self):
-        last_modified = datetime.datetime.now()
+        last_modified = datetime.datetime.utcnow()
         playlist = Playlist(last_modified=last_modified)
         self.assertEqual(playlist.last_modified, last_modified)
         self.assertRaises(
@@ -715,7 +715,7 @@ class PlaylistTest(unittest.TestCase):
 
     def test_with_new_uri(self):
         tracks = [Track()]
-        last_modified = datetime.datetime.now()
+        last_modified = datetime.datetime.utcnow()
         playlist = Playlist(
             uri='an uri', name='a name', tracks=tracks,
             last_modified=last_modified)
@@ -727,7 +727,7 @@ class PlaylistTest(unittest.TestCase):
 
     def test_with_new_name(self):
         tracks = [Track()]
-        last_modified = datetime.datetime.now()
+        last_modified = datetime.datetime.utcnow()
         playlist = Playlist(
             uri='an uri', name='a name', tracks=tracks,
             last_modified=last_modified)
@@ -739,7 +739,7 @@ class PlaylistTest(unittest.TestCase):
 
     def test_with_new_tracks(self):
         tracks = [Track()]
-        last_modified = datetime.datetime.now()
+        last_modified = datetime.datetime.utcnow()
         playlist = Playlist(
             uri='an uri', name='a name', tracks=tracks,
             last_modified=last_modified)
@@ -752,7 +752,7 @@ class PlaylistTest(unittest.TestCase):
 
     def test_with_new_last_modified(self):
         tracks = [Track()]
-        last_modified = datetime.datetime.now()
+        last_modified = datetime.datetime.utcnow()
         new_last_modified = last_modified + datetime.timedelta(1)
         playlist = Playlist(
             uri='an uri', name='a name', tracks=tracks,
@@ -862,10 +862,56 @@ class PlaylistTest(unittest.TestCase):
 
     def test_ne(self):
         playlist1 = Playlist(
-            uri='uri1', name='name2', tracks=[Track(uri='uri1')],
+            uri='uri1', name='name1', tracks=[Track(uri='uri1')],
             last_modified=1)
         playlist2 = Playlist(
             uri='uri2', name='name2', tracks=[Track(uri='uri2')],
             last_modified=2)
         self.assertNotEqual(playlist1, playlist2)
         self.assertNotEqual(hash(playlist1), hash(playlist2))
+
+
+class SearchResultTest(unittest.TestCase):
+    def test_uri(self):
+        uri = 'an_uri'
+        result = SearchResult(uri=uri)
+        self.assertEqual(result.uri, uri)
+        self.assertRaises(AttributeError, setattr, result, 'uri', None)
+
+    def test_tracks(self):
+        tracks = [Track(), Track(), Track()]
+        result = SearchResult(tracks=tracks)
+        self.assertEqual(list(result.tracks), tracks)
+        self.assertRaises(AttributeError, setattr, result, 'tracks', None)
+
+    def test_artists(self):
+        artists = [Artist(), Artist(), Artist()]
+        result = SearchResult(artists=artists)
+        self.assertEqual(list(result.artists), artists)
+        self.assertRaises(AttributeError, setattr, result, 'artists', None)
+
+    def test_albums(self):
+        albums = [Album(), Album(), Album()]
+        result = SearchResult(albums=albums)
+        self.assertEqual(list(result.albums), albums)
+        self.assertRaises(AttributeError, setattr, result, 'albums', None)
+
+    def test_invalid_kwarg(self):
+        test = lambda: SearchResult(foo='baz')
+        self.assertRaises(TypeError, test)
+
+    def test_repr_without_results(self):
+        self.assertEquals(
+            "SearchResult(albums=[], artists=[], tracks=[], uri=u'uri')",
+            repr(SearchResult(uri='uri')))
+
+    def test_serialize_without_results(self):
+        self.assertDictEqual(
+            {'__model__': 'SearchResult', 'uri': 'uri'},
+            SearchResult(uri='uri').serialize())
+
+    def test_to_json_and_back(self):
+        result1 = SearchResult(uri='uri')
+        serialized = json.dumps(result1, cls=ModelJSONEncoder)
+        result2 = json.loads(serialized, object_hook=model_json_decoder)
+        self.assertEqual(result1, result2)
